@@ -73,6 +73,30 @@ class Customer(object):
             customers = [Customer(row.name, **kwargs) for row in rows]
         return customers
 
+    def customers_fup(self):
+        """get info client fupé|défupé"""
+        infos = {}
+        url = core.database_url(**FUPDB_CREDENTIALS)
+        with records.Database(url) as db:
+            sql = (
+                "SELECT policy,datetime,customer, status, conso FROM fup "
+                "WHERE customer=:customer and datetime=(SELECT max(datetime)"
+                " from fup WHERE customer=:customer)"
+                )
+            LOGS.logger.info(sql)
+            rows = db.query(
+                sql,
+                customer=self.name,
+                )
+            for row in rows:
+                infos = {
+                    'customer': row.customer,
+                    'status': row.status,
+                    'conso': row.conso,
+                    'policy': row.policy
+                    }
+        return infos
+
     @property
     def fup_status(self):
         """Retourne le status FUP du client"""
@@ -140,75 +164,160 @@ class Customer(object):
         LOGS.logger.info(log_msg)
         self.product = product.Product(product_name)
 
-    def defup_from_aiguillier(self):
-        """défuper un client qui est fupé"""
+    def start_consumptions(self, start_conso):
+        """enregistre dans redis la date a partir de """
+        """laquelle on calcul la conso fup d'un client"""
         result = {}
+        key = 'cdr_start_date:{}'.format(self.name)
+        REDIS_DB.set(key, start_conso)
+        REDIS_DB.expire(key, 30)
+        start = REDIS_DB.get(key)
+        result = {
+                'code': '200',
+                'ident': self.name,
+                'date': str(start.decode('utf-8'))
+                }
+        return result
+
+    def fup_defup(
+            self,
+            method,
+            params,
+            policy_name,
+            db_status,
+            conso,
+            period,
+            msg
+            ):
+        api_request = getattr(REST_CLIENT, method)
+        LOGS.logger.info(api_request)
+        LOGS.logger.info(params)
+        response = api_request(
+            '/fup',
+            auth=(
+                CONFIG['AIGUILLIER']['username'],
+                CONFIG['AIGUILLIER']['password']
+                ),
+            params=params
+            )
+        LOGS.logger.info('AIGUILLIER RESPONSE: {}'.format(
+            response['content']
+            ))
+        LOGS.logger.info("{} un client {}-{}-{}-{}".format(
+            msg,
+            self.name,
+            policy_name,
+            period,
+            response['content']['status']
+            ))
+        if (response['content']['status']).lower() == '200':
+            url = core.database_url(**FUPDB_CREDENTIALS)
+            with records.Database(url) as db:
+                sql = (
+                    "INSERT INTO fup "
+                    "(customer, product, policy, datetime, status, "
+                    "conso) "
+                    "VALUES "
+                    "(:name, :product, :policy, :date_time, :status, "
+                    ":conso)"
+                    )
+                db.query(
+                    sql,
+                    name=self.name,
+                    product=self.product.name,
+                    policy=policy_name,
+                    date_time=datetime.now(),
+                    status=db_status,
+                    conso=str(conso)
+                    )
+            result = {
+                'code': '200',
+                'message': '{} reussit'.format(msg)
+                }
+        else:
+            result = {
+                'code': '400',
+                'message': 'ERROR {} COTE AIGUILLIER'.format(msg)
+                }
+        return result
+
+    def defup_from_aiguillier(self, bool_defup):
+        """défuper ou fuper un client"""
+        result = {
+            'code': '401',
+            'message': 'NOK'
+            }
+        params = {}
+        params['customer'] = self.name
+        if bool_defup:
+            msg = 'Defup'
+            db_status = False
+        else:
+            msg = 'Fup'
+            db_status = True
         customer_status = self.fup_status
         for policy_name in self.product.policies:
             status = customer_status.get(policy_name)
             policy_name_tab = policy_name.rsplit('_', 1)
+            method = 'post'
             if policy_name_tab[1] == '2':
                 period = 'hc'
+                params['period'] = period
+            elif policy_name_tab[1] == '3':
+                period = 'try'
+                if bool_defup:
+                    params['actif'] = 'FALSE'
+                    msg = 'Active'
+                else:
+                    msg = 'Desactive'
+                    params['actif'] = 'TRUE'
             else:
                 period = 'hp'
+                params['period'] = period
             if status:
                 status = sorted(
                     status,
                     key=lambda x: x['datetime'],
                     reverse=True
                     )
-                if status[0]['status']:
-                    # si le client était fup, il faut le défup
-                    REST_CLIENT.delete(
-                        '/fup',
-                        auth=(
-                            CONFIG['AIGUILLIER']['username'],
-                            CONFIG['AIGUILLIER']['password']
-                            ),
-                        params={
-                            'customer': self.name,
-                            'period': period
-                        }
-                        )
-                    LOGS.logger.info("Defuper un client {}-{}-{}".format(
-                        self.name,
+                if status[0]['status'] == bool_defup:
+                    result = self.fup_defup(
+                        method,
+                        params,
                         policy_name,
-                        period
-                        ))
-                    url = core.database_url(**FUPDB_CREDENTIALS)
-                    with records.Database(url) as db:
-                        sql = (
-                            "INSERT INTO fup "
-                            "(customer, product, policy, datetime, status) "
-                            "VALUES "
-                            "(:name, :product, :policy, :date_time, :status)"
-                            )
-                        db.query(
-                            sql,
-                            name=self.name,
-                            product=self.product.name,
-                            policy=policy_name,
-                            date_time=datetime.now(),
-                            status=False
-                            )
-                    result = {
-                        'code': '200',
-                        'message': 'défup reussit'
-                        }
+                        db_status,
+                        '0.0',
+                        period,
+                        msg
+                        )
                 else:
                     result = {
                             'code': '201',
-                            'message': 'deja fupé'
+                            'message': 'deja {}'.format(msg)
                             }
             else:
-                result = {
-                        'code': '204',
-                        'message': 'produit non fupé'
-                        }
-        url = core.database_url(**FUPDB_CREDENTIALS)
-        with records.Database(url) as db:
-            sql = "DELETE FROM customer WHERE name=:name"
-            db.query(sql, name=self.name)
+                if not status and not bool_defup:
+                    LOGS.logger.info('innnnnnnnn')
+                    result = self.fup_defup(
+                        method,
+                        params,
+                        policy_name,
+                        db_status,
+                        '0.0',
+                        period,
+                        msg
+                        )
+                else:
+                    result = {
+                            'code': '204',
+                            'message': 'produit non {}'.format(msg)
+                            }
+        """if bool_defup:
+            url = core.database_url(**FUPDB_CREDENTIALS)
+            with records.Database(url) as db:
+                sql = "DELETE FROM customer WHERE name=:name"
+                db.query(sql, name=self.name)
+        """
         return result
 
     def get_cdr_from_aiguillier(self, last_date):
@@ -536,6 +645,8 @@ class Customer(object):
             policy_name_tab = policy_name.rsplit('_', 1)
             if policy_name_tab[1] == '2':
                 info['period'] = 'hc'
+            elif policy_name_tab[1] == '3':
+                info['period'] = 'try'
             else:
                 info['period'] = 'hp'
             info['sources'] = [
@@ -554,6 +665,7 @@ class Customer(object):
         # on vérifie si le client a une configuration particulière
         # pour la date à laquelle on doit commencer à compter
         # sa consommation
+        params = {}
         key = 'cdr_start_date:{}'.format(self.name)
         start = REDIS_DB.get(key)  # s'il n'y a pas de clés ce sera None
         if start:
@@ -588,7 +700,21 @@ class Customer(object):
                 info['fup_out'] = True
             if for_real:
                 if info.get('fup_in'):  # à limiter
-                    url = core.database_url(**FUPDB_CREDENTIALS)
+                    if info['period'] == 'try':
+                        params['actif'] = 'TRUE'
+                    else:
+                        params['period'] = info['period']
+                    params['customer'] = self.name
+                    self.fup_defup(
+                        'post',
+                        params,
+                        info['name'],
+                        True,
+                        str(info['total']),
+                        str(info['period']),
+                        'Fup'
+                        )
+                    """url = core.database_url(**FUPDB_CREDENTIALS)
                     with records.Database(url) as db:
                         sql = (
                             "INSERT INTO fup "
@@ -607,19 +733,38 @@ class Customer(object):
                             status=True,
                             conso=str(info['total'])
                             )
+                    if info['period'] == 'try':
+                        params['actif'] = True
+                    else:
+                        params['period'] = info['period']
+                    params['customer'] = self.name
                     REST_CLIENT.post(
                         '/fup',
                         auth=(
                             CONFIG['AIGUILLIER']['username'],
                             CONFIG['AIGUILLIER']['password']
                             ),
-                        params={
-                            'customer': self.name,
-                            'period': info['period']
-                            }
+                        params=params
                         )
+                    """
                 elif info.get('fup_out'):  # libérer
-                    url = core.database_url(**FUPDB_CREDENTIALS)
+                    if info['period'] == 'try':
+                        params['actif'] = 'FALSE'
+                        method = 'post'
+                    else:
+                        params['period'] = info['period']
+                        method = 'delete'
+                    params['customer'] = self.name
+                    self.fup_defup(
+                        method,
+                        params,
+                        info['name'],
+                        False,
+                        str(info['total']),
+                        str(info['period']),
+                        'Defup'
+                        )
+                    """url = core.database_url(**FUPDB_CREDENTIALS)
                     with records.Database(url) as db:
                         sql = (
                             "INSERT INTO fup "
@@ -638,17 +783,20 @@ class Customer(object):
                             status=False,
                             conso=str(info['total'])
                             )
+                    if info['period'] == 'try':
+                        params['actif'] = False
+                    else:
+                        params['period'] = info['period']
+                    params['customer'] = self.name
                     REST_CLIENT.delete(
                         '/fup',
                         auth=(
                             CONFIG['AIGUILLIER']['username'],
                             CONFIG['AIGUILLIER']['password']
                             ),
-                        params={
-                            'customer': self.name,
-                            'period': info['period']
-                            }
+                        params=params
                         )
+                    """
         return cdrs_by_policies
 
     def get_cdr_summary(
