@@ -35,6 +35,7 @@ class Product_GP(object):
         self.username = kwargs.get('username', 'fup-services')
         self.type_ident = kwargs.get('type_ident', 'msisdn')
         self.produit_nom = kwargs.get('produit_nom')
+        self.date_try = kwargs.get('date_try')
 
     def __repr__(self):
         return(
@@ -92,6 +93,8 @@ class Product_GP(object):
                     'type_ident': info['type_ident'].lower(),
                     'produit_nom': info['produit_nom'].lower()
                     }
+                if product_type == 'try_airfiber':
+                    kwargs['date_try'] = info['try_af_datefin']
                 result.append(Product_GP(name, ident, **kwargs))
             return result
 
@@ -157,7 +160,7 @@ class Product_GP(object):
                 float(i['total_for_fup_HO'])
                 for i in consos
                 ])
-            click.echo(value)
+            LOGS.logger.info(value)
             return float(value)
 
         else:
@@ -200,6 +203,82 @@ class Product_GP(object):
         de la limite autorisée"""
         return float((self.consumption / self.limit) * 100)
 
+    def sender_mail(
+            self,
+            message,
+            obj,
+            from_0,
+            to,
+            key,
+            tag,
+            conso,
+            limit,
+            remaining_seconds
+            ):
+        dest = to.split(',')
+        today = datetime.now()
+        content = MIMEText(message, 'plain', 'utf-8')
+        msg = MIMEMultipart()
+        msg['Subject'] = ('[blueline] {object}').format(object=obj)
+        msg['From'] = from_0
+        msg['To'] = to
+        msg.attach(content)
+        s = smtplib.SMTP('localhost')
+        s.sendmail(
+            from_0,
+            dest,
+            msg.as_string()
+            )
+        s.quit()
+        REDIS_DB.hmset(
+            '{}:{}'.format(key, tag),
+            {
+                'date': today.strftime('%d%m%Y'),
+                'consumption': conso,
+                'limit': limit
+                }
+            )
+        REDIS_DB.expire(
+            '{}:{}'.format(key, tag),
+            remaining_seconds
+            )
+
+    def sender_sms(
+            self,
+            APIGW,
+            username,
+            sms,
+            phonenumber,
+            key,
+            tag,
+            conso,
+            limit,
+            remaining_seconds
+            ):
+        today = datetime.now()
+        requests.post(
+            url='https://{fqdn}/smsc/v1/sms'.format(
+                fqdn=APIGW
+                ),
+            auth=(username, ''),
+            json={
+                'message': sms,
+                'msisdn': phonenumber
+                }
+            )
+        REDIS_DB.hmset(
+            '{}:{}'.format(key, tag),
+            {
+                'date': today.strftime('%d%m%Y'),
+                'consumption': conso,
+                'limit': limit
+                }
+            )
+        REDIS_DB.expire(
+            '{}:{}'.format(key, tag),
+            remaining_seconds
+            )
+
     def notify(self, start_date, stop_date):
         """Notification"""
         key = 'notification:{ident}'.format(ident=self.ident)
@@ -225,18 +304,6 @@ class Product_GP(object):
             if self.notif_mail_percentage:
                 if percentage >= self.notif_mail_percentage:
                     if self.send_sms == 'faux':
-                        """message = (
-                            "Cher client, vous vous approchez "
-                            "d’une consommation mensuelle équivalente "
-                            "au double de la consommation moyenne des "
-                            "utilisateurs internet particuliers.\n"
-                            "Arrivé à 100 Go d’usage, le débit de votre "
-                            "connexion sera dégradé.\n"
-                            "Nous vous invitons à consulter vos "
-                            "dernières consommations sur le site "
-                            "http://espace-client.blueline.mg"
-                            )
-                        """
                         message = (
                                 "Cher Mr/Mme {name}, ayant souscrit au produit"
                                 " {produit},\n\nVotre consommation internet"
@@ -272,18 +339,6 @@ class Product_GP(object):
                             ).format(produit=self.produit_nom)
                     elif self.send_sms == 'vrai':
                         if self.type_ident == 'mac':
-                            """message = (
-                                "Cher client {name}, Vous vous approchez "
-                                "d’une consommation mensuelle équivalente "
-                                "au double de la consommation moyenne des "
-                                "utilisateurs internet particuliers.\n"
-                                "Arrivé à 100 Go d’usage, le débit de votre "
-                                "connexion sera dégradé.\n"
-                                "Nous vous invitons à consulter vos "
-                                "dernières consommations sur le site "
-                                "http://espace-client.blueline.mg"
-                                ).format(name=self.customer_name)
-                            """
                             message = (
                                 "Cher Mr/Mme {name}, ayant souscrit au produit"
                                 " {produit},\n\nVotre consommation internet"
@@ -359,7 +414,18 @@ class Product_GP(object):
                                 " produit {produit}"
                                 ).format(produit=self.produit_nom)
                     # envoyer msg
-                    content = MIMEText(message, 'plain', 'utf-8')
+                    self.sender_mail(
+                        message,
+                        obj,
+                        CONFIG['ALERT']['from_1'],
+                        self.email,
+                        key,
+                        'email',
+                        consumption,
+                        self.limit,
+                        remaining_seconds
+                        )
+                    """content = MIMEText(message, 'plain', 'utf-8')
                     msg = MIMEMultipart()
                     msg['Subject'] = ('[blueline] {object}').format(object=obj)
                     msg['From'] = CONFIG['ALERT']['from_1']
@@ -373,17 +439,18 @@ class Product_GP(object):
                         )
                     s.quit()
                     REDIS_DB.hmset(
-                        '{}:email'.format(key),
+                        '{}:{}'.format(key,tag),
                         {
                             'date': today.strftime('%d%m%Y'),
-                            'consumption': consumption,
+                            'consumption': conso,
                             'limit': self.limit
                             }
                         )
                     REDIS_DB.expire(
-                        '{}:email'.format(key),
+                        '{}:{}'.format(key,tag),
                         remaining_seconds
                         )
+                    """
                     status = True
             return 'email', percentage, status
         elif last_notification_email and not last_notification_sms:
@@ -412,7 +479,18 @@ class Product_GP(object):
                                 ).format(
                                     limit=round(self.limit / 1000000000)
                                     )
-                        requests.post(
+                        self.sender_sms(
+                            APIGW,
+                            self.username,
+                            sms,
+                            self.phonenumber,
+                            key,
+                            'sms',
+                            consumption,
+                            self.limit,
+                            remaining_seconds
+                            )
+                        """requests.post(
                             url='https://{fqdn}/smsc/v1/sms'.format(
                                 fqdn=APIGW
                                 ),
@@ -423,20 +501,268 @@ class Product_GP(object):
                                 }
                             )
                         REDIS_DB.hmset(
-                            '{}:sms'.format(key),
+                            '{}:{}'.format(key,tag),
                             {
                                 'date': today.strftime('%d%m%Y'),
-                                'consumption': consumption,
+                                'consumption': conso,
                                 'limit': self.limit
                                 }
                             )
                         REDIS_DB.expire(
-                            '{}:sms'.format(key),
+                            '{}:{}'.format(key,tag),
                             remaining_seconds
                             )
+                        """
                         status = True
             return 'sms', percentage, status
         else:
             return None
 
+    def notify_try(self, start_date, stop_date):
+        """Notification"""
+        key = 'notification:{ident}'.format(ident=self.ident)
+        today = datetime.now()
+        # last_day_of_month = calendar.monthrange(today.year, today.month)[1]
+        remaining_seconds = 1209600
+        last_notification_email_conso = REDIS_DB.hget(
+            '{}:emailconso'.format(key),
+            'date'
+            )
+        last_notification_sms_conso = REDIS_DB.hget(
+            '{}:smsconso'.format(key),
+            'date'
+            )
+        last_notification_email_date = REDIS_DB.hget(
+            '{}:emaildate'.format(key),
+            'date'
+            )
+        last_notification_sms_date = REDIS_DB.hget(
+            '{}:smsdate'.format(key),
+            'date'
+            )
+        consumption = self.consumption(start_date, stop_date)
+        percentage = (round(float(consumption)) / self.limit) * 100
+        status = False
+        tag = 'NOK'
+        click.echo('notif_mail {}'.format(self.notif_mail_percentage))
+        click.echo('notif_sms {}'.format(self.notif_sms_percentage))
+        date_try_minus = datetime.strptime(
+                self.date_try,
+                '%d/%m/%Y'
+                ) - timedelta(4)
+        date_alert_2 = datetime.strptime(
+            today.strftime('%d/%m/%Y'),
+            '%d/%m/%Y'
+            )
+        # date_try_minus = datetime.strftime(date_try_minus, '%d/%m/%Y')
+        # date_alert_2 = datetime.strftime(today, '%d/%m/%Y')
+        click.echo('notif_mail date_try_minus {}'.format(
+            str(date_try_minus)
+            ))
+        click.echo('notif_sms date du jour {}'.format(
+            str(date_alert_2)
+            ))
+        click.echo('last_notification_email_date{}'.format(
+            str(last_notification_email_date)
+            ))
+        click.echo('last_notification_sms_date {}'.format(
+            str(last_notification_sms_date)
+            ))
+        condition_conso = (
+            not last_notification_email_conso
+            and
+            not last_notification_sms_conso
+            )
+        obj = ("Notification période d’essai AirFiber")
+        email = str(self.email)
+        if condition_conso:
+            # aucune notification durant ce mois
+            # on fait une notification par email
+            if self.notif_mail_percentage and self.notif_sms_percentage:
+                if percentage >= self.notif_sms_percentage:
+                    message = (
+                        "Bonjour,\n\nLe client au nom de Mr/Mme {name}, "
+                        "inscrit sur la période d’essai AirFiber a atteint"
+                        " son quota de 25 Go. Merci de le rappeler afin de "
+                        "finaliser sa période d’essai au {contact}"
+                        ".\n\nCordialement,").format(
+                        name=self.customer_name,
+                        contact=self.phonenumber
+                        )
+                    sms = (
+                        "Vous avez consomme les 25 Go de votre periode "
+                        "d'essai Airfiber. Vous serez prochainement "
+                        "recontacte par notre service client. "
+                        "Blueline vous remercie."
+                        )
+                    tag = 'smsconso'
+                    email += ','+str(CONFIG['ALERT']['to_com_supp_adv'])
+                    status = True
+                    self.sender_sms(
+                        APIGW,
+                        self.username,
+                        sms,
+                        self.phonenumber,
+                        key,
+                        tag,
+                        consumption,
+                        self.limit,
+                        remaining_seconds
+                        )
+                elif percentage >= self.notif_mail_percentage:
+                    limit = round(self.limit / 1000000000)
+                    message = (
+                        "Cher Mr/Mme {name}, étant en essai du "
+                        "produit Airfiber,\n\nVous avez consommé {x}% "
+                        "des {limit} Go de votre période d’essai. Pour "
+                        "vous aider à maitriser votre usage, nous "
+                        "vous invitons à vous connecter sur votre "
+                        "espace client http://espace-client.blueline.mg "
+                        "et ainsi suivre votre consommation.\n\nSi vous "
+                        "souhaitez vous faire assister, notre service "
+                        "de support client est disponible 24/7 au 0 391 "
+                        "391 391.\n\nBlueline vous remercie."
+                        ).format(
+                        x=self.notif_mail_percentage,
+                        name=self.customer_name,
+                        limit=limit
+                        )
+                    tag = 'emailconso'
+                    status = True
+                    email += ','+str(CONFIG['ALERT']['to_supp'])
+                # envoyer msg
+                click.echo('email {}'.format(
+                    CONFIG['ALERT']['to_com_supp_adv']
+                    ))
+                click.echo('email {}'.format(email))
+                if status:
+                    self.sender_mail(
+                        message,
+                        obj,
+                        CONFIG['ALERT']['from_1'],
+                        email,
+                        key,
+                        tag,
+                        consumption,
+                        self.limit,
+                        remaining_seconds
+                        )
+                    return tag, percentage, status
+                """content = MIMEText(message, 'plain', 'utf-8')
+                msg = MIMEMultipart()
+                msg['Subject'] = ('[blueline] {object}').format(object=obj)
+                msg['From'] = CONFIG['ALERT']['from_1']
+                msg['To'] = self.email
+                msg.attach(content)
+                s = smtplib.SMTP('localhost')
+                s.sendmail(
+                    CONFIG['ALERT']['from_1'],
+                    [self.email],
+                    msg.as_string()
+                    )
+                s.quit()
+                REDIS_DB.hmset(
+                    '{}:emailconso'.format(key),
+                    {
+                        'date': today.strftime('%d%m%Y'),
+                        'consumption': consumption,
+                        'limit': self.limit
+                        }
+                    )
+                REDIS_DB.expire(
+                    '{}:emailconso'.format(key),
+                    remaining_seconds
+                    )
+                status = True
+                """
+        elif last_notification_email_conso and not last_notification_sms_conso:
+            # on fait une notification par SMS
+            if self.notif_sms_percentage:
+                if percentage >= self.notif_sms_percentage:
+                    message = (
+                        "Bonjour,\n\nLe client au nom de Mr/Mme {name}, "
+                        "inscrit sur la période d’essai AirFiber a atteint"
+                        " son quota de 25 Go. Merci de le rappeler afin de "
+                        "finaliser sa période d’essai au {contact}"
+                        ".\n\nCordialement,").format(
+                        name=self.customer_name,
+                        contact=self.phonenumber
+                        )
+                    sms = (
+                        "Vous avez consomme les 25 Go de votre periode "
+                        "d'essai Airfiber. Vous serez prochainement "
+                        "recontacte par notre service client.\n\n"
+                        "Blueline vous remercie."
+                        )
+                    tag = 'smsconso'
+                    email += ','+str(CONFIG['ALERT']['to_com_supp_adv'])
+                    status = True
+                    self.sender_sms(
+                        APIGW,
+                        self.username,
+                        sms,
+                        self.phonenumber,
+                        key,
+                        tag,
+                        consumption,
+                        self.limit,
+                        remaining_seconds
+                        )
+                    self.sender_mail(
+                        message,
+                        obj,
+                        CONFIG['ALERT']['from_1'],
+                        email,
+                        key,
+                        tag,
+                        consumption,
+                        self.limit,
+                        remaining_seconds
+                        )
+                    return tag, percentage, status
+        else:
+            return None
+        if not last_notification_sms_conso:
+            condition_date = (
+                not last_notification_email_date
+                and
+                not last_notification_sms_date
+                )
+            if condition_date:
+                click.echo('in1')
+                if date_try_minus <= date_alert_2:
+                    click.echo('in2')
+                    message = (
+                        "Cher Mr/Mme {name}, étant en essai "
+                        "du produit Airfiber,\n\nVotre période "
+                        "d’essai pour le produit AirFiber sera "
+                        "terminée le {date}. Votre consommation "
+                        "est visible sur votre espace client "
+                        "http://espace-client.blueline.mg.\n\n"
+                        "Si vous souhaitez vous faire assister, "
+                        "notre service de support client est "
+                        "disponible 24/7 au 0 391 391 391.\n\n"
+                        "Blueline vous remercie."
+                        ).format(
+                        name=self.customer_name,
+                        date=self.date_try
+                        )
+                    status = True
+                    email += ','+str(CONFIG['ALERT']['to_com_supp_adv'])
+                    self.sender_mail(
+                        message,
+                        obj,
+                        CONFIG['ALERT']['from_1'],
+                        email,
+                        key,
+                        'emaildate',
+                        consumption,
+                        self.limit,
+                        remaining_seconds
+                        )
+                    return 'emaildate', percentage, status
+        else:
+            return None
+
+
 # EOF
